@@ -10,20 +10,23 @@ from .user_utils import get_or_create_user
 def patch_jwt_settings():
     """Patch rest_framework_jwt authentication settings from allauth"""
     defaults = api_settings.defaults
-    defaults['JWT_PAYLOAD_GET_USER_ID_HANDLER'] = (
-        __name__ + '.get_user_id_from_payload_handler')
+    defaults["JWT_PAYLOAD_GET_USER_ID_HANDLER"] = (
+        __name__ + ".get_user_id_from_payload_handler"
+    )
 
-    if 'allauth.socialaccount' not in settings.INSTALLED_APPS:
+    if "allauth.socialaccount" not in settings.INSTALLED_APPS:
         return
 
     from allauth.socialaccount.models import SocialApp
+
     try:
-        app = SocialApp.objects.get(provider='helsinki')
+        app = SocialApp.objects.get(provider="helsinki")
     except SocialApp.DoesNotExist:
         return
 
-    defaults['JWT_SECRET_KEY'] = app.secret
-    defaults['JWT_AUDIENCE'] = app.client_id
+    defaults["JWT_SECRET_KEY"] = app.secret
+    defaults["JWT_AUDIENCE"] = app.client_id
+
 
 # Disable automatic settings patching for now because it breaks Travis.
 # patch_jwt_settings()
@@ -37,11 +40,11 @@ class JWTAuthentication(JSONWebTokenAuthentication):
             raise exceptions.AuthenticationFailed(str(e)) from e
 
         if user and not user.is_active:
-            msg = _('User account is disabled.')
+            msg = _("User account is disabled.")
             raise exceptions.AuthenticationFailed(msg)
 
         return user
 
 
 def get_user_id_from_payload_handler(payload):
-    return payload.get('sub')
+    return payload.get("sub")
